@@ -26,9 +26,7 @@
 #       You may only use this script to uninstall the version
 #       shown below. Simply run this script to remove Shorewall Firewall
 
-VERSION=5.1.2.1
-PRODUCT=shorewall
-Product=Shorewall
+VERSION=5.1.3
 
 usage() # $1 = exit status
 {
@@ -41,51 +39,27 @@ usage() # $1 = exit status
     exit $1
 }
 
-fatal_error()
-{
-    echo "   ERROR: $@" >&2
-    exit 1
-}
-
-qt()
-{
-    "$@" >/dev/null 2>&1
-}
-
-split() {
-    local ifs
-    ifs=$IFS
-    IFS=:
-    set -- $1
-    echo $*
-    IFS=$ifs
-}
-
-mywhich() {
-    local dir
-
-    for dir in $(split $PATH); do
-	if [ -x $dir/$1 ]; then
-	    return 0
-	fi
-    done
-
-    return 2
-}
-
-remove_file() # $1 = file to restore
-{
-    if [ -f $1 -o -L $1 ] ; then
-	rm -f $1
-	echo "$1 Removed"
-    fi
-}
-
 #
 # Change to the directory containing this script
 #
 cd "$(dirname $0)"
 
+if [ -f shorewall.service ]; then
+    PRODUCT=shorewall
+    Product=Shorewall
+else
+    PRODUCT=shorewall6
+    Product=Shorewall6
+fi
+
+#
+# Source common functions
+#
+. ./lib.uninstaller || { echo "ERROR: Can not load common functions." >&2; exit 1; }
+
+#
+# Parse the run line
+#
 finished=0
 configure=1
 
@@ -102,7 +76,7 @@ while [ $finished -eq 0 ]; do
 			usage 0
 			;;
 		    v)
-			echo "$Product Firewall Installer Version $VERSION"
+			echo "$Product Firewall Uninstaller Version $VERSION"
 			exit 0
 			;;
 		    n*)
@@ -123,13 +97,16 @@ while [ $finished -eq 0 ]; do
     esac
 done
 
+#
+# Read the RC file
+#
 if [ $# -eq 0 ]; then
     if [ -f ./shorewallrc ]; then
-	. ./shorewallrc
+        . ./shorewallrc || fatal_error "Can not load the RC file: ./shorewallrc"
     elif [ -f ~/.shorewallrc ]; then
-	. ~/.shorewallrc || exit 1
+        . ~/.shorewallrc || fatal_error "Can not load the RC file: ~/.shorewallrc"
     elif [ -f /usr/share/shorewall/shorewallrc ]; then
-	. /usr/share/shorewall/shorewallrc
+        . /usr/share/shorewall/shorewallrc || fatal_error "Can not load the RC file: /usr/share/shorewall/shorewallrc"
     else
 	fatal_error "No configuration file specified and /usr/share/shorewall/shorewallrc not found"
     fi
@@ -139,52 +116,53 @@ elif [ $# -eq 1 ]; then
 	/*|.*)
 	    ;;
 	*)
-	    file=./$file
+	    file=./$file || exit 1
 	    ;;
     esac
 
-    . $file
+    . $file || fatal_error "Can not load the RC file: $file"
 else
     usage 1
 fi
 
-if [ -f ${SHAREDIR}/shorewall/version ]; then
-    INSTALLED_VERSION="$(cat ${SHAREDIR}/shorewall/version)"
+if [ -f ${SHAREDIR}/$PRODUCT/version ]; then
+    INSTALLED_VERSION="$(cat ${SHAREDIR}/$PRODUCT/version)"
     if [ "$INSTALLED_VERSION" != "$VERSION" ]; then
-	echo "WARNING: Shorewall Version $INSTALLED_VERSION is installed"
+	echo "WARNING: $Product Version $INSTALLED_VERSION is installed"
 	echo "         and this is the $VERSION uninstaller."
 	VERSION="$INSTALLED_VERSION"
     fi
 else
-    echo "WARNING: Shorewall Version $VERSION is not installed"
+    echo "WARNING: $Product Version $VERSION is not installed"
     VERSION=""
 fi
 
-
-echo "Uninstalling shorewall $VERSION"
+echo "Uninstalling $Product $VERSION"
 
 [ -n "$SANDBOX" ] && configure=0
 
 if [ $configure -eq 1 ]; then
     if qt iptables -L shorewall -n && [ ! -f ${SBINDIR}/shorewall-lite ]; then
-	shorewall clear
+	${SBINDIR}/$PRODUCT clear
+    elif qt ip6tables -L shorewall6 -n && [ ! -f ${SBINDIR}/shorewall6-lite ]; then
+	${SBINDIR}/$PRODUCT clear
     fi
 fi
 
-rm -f ${SBINDIR}/shorewall
+remove_file ${SBINDIR}/$PRODUCT
 
-if [ -L ${SHAREDIR}/shorewall/init ]; then
-    FIREWALL=$(readlink -m -q ${SHAREDIR}/shorewall/init)
+if [ -L ${SHAREDIR}/$PRODUCT/init ]; then
+    FIREWALL=$(readlink -m -q ${SHAREDIR}/$PRODUCT/init)
 elif [ -n "$INITFILE" ]; then
     FIREWALL=${INITDIR}/${INITFILE}
 fi
 
 if [ -f "$FIREWALL" ]; then
     if [ $configure -eq 1 ]; then
-	if mywhich updaterc.d ; then
-	    updaterc.d ${PRODUCT} remove
-	elif mywhich insserv ; then
+	if mywhich insserv ; then
             insserv -r $FIREWALL
+	elif mywhich update-rc.d ; then
+	    update-rc.d ${PRODUCT} remove
 	elif mywhich chkconfig ; then
 	    chkconfig --del $(basename $FIREWALL)
 	fi
@@ -193,51 +171,56 @@ if [ -f "$FIREWALL" ]; then
     remove_file $FIREWALL
 fi
 
-if [ -z "${SERVICEDIR}" ]; then
-    SERVICEDIR="$SYSTEMD"
-fi
+[ -z "${SERVICEDIR}" ] && SERVICEDIR="$SYSTEMD"
+
 if [ -n "$SERVICEDIR" ]; then
-    [ $configure -eq 1 ] && systemctl disable ${PRODUCT}
-    rm -f $SERVICEDIR/shorewall.service
+    [ $configure -eq 1 ] && systemctl disable ${PRODUCT}.service
+    remove_file $SERVICEDIR/${PRODUCT}.service
 fi
 
-rm -rf ${SHAREDIR}/shorewall/version
-rm -rf ${CONFDIR}/shorewall
+remove_file ${SHAREDIR}/$PRODUCT/version
+remove_directory ${CONFDIR}/$PRODUCT
 
 if [ -n "$SYSCONFDIR" ]; then
-    [ -n "$SYSCONFFILE" ] && rm -f ${SYSCONFDIR}/${PRODUCT}
+    [ -n "$SYSCONFFILE" ] && remove_file ${SYSCONFDIR}/${PRODUCT}
 fi
 
-rm -rf ${VARDIR}/shorewall
-rm -rf ${PERLLIBDIR}/Shorewall/*
-[ ${LIBEXECDIR} = ${SHAREDIR} ] || rm -rf ${LIBEXECDIR}/shorewall
-rm -rf ${SHAREDIR}/shorewall/configfiles/
-rm -rf ${SHAREDIR}/shorewall/Samples/
-rm -rf ${SHAREDIR}/shorewall/Shorewall/
-rm -f  ${SHAREDIR}/shorewall/lib.cli-std
-rm -f  ${SHAREDIR}/shorewall/lib.runtime
-rm -f  ${SHAREDIR}/shorewall/compiler.pl
-rm -f  ${SHAREDIR}/shorewall/prog.*
-rm -f  ${SHAREDIR}/shorewall/module*
-rm -f  ${SHAREDIR}/shorewall/helpers
-rm -f  ${SHAREDIR}/shorewall/action*
-rm -f  ${SHAREDIR}/shorewall/macro.*
-rm -f  ${SHAREDIR}/shorewall/init
+remove_directory ${VARDIR}
+[ ${LIBEXECDIR} = ${SHAREDIR} ] || remove_directory ${LIBEXECDIR}/$PRODUCT
+remove_directory ${SHAREDIR}/$PRODUCT/configfiles
+remove_file_with_wildcard  ${SHAREDIR}/$PRODUCT/module\*
+remove_file  ${SHAREDIR}/$PRODUCT/helpers
+remove_file_with_wildcard  ${SHAREDIR}/$PRODUCT/action\*
+remove_file_with_wildcard  ${SHAREDIR}/$PRODUCT/macro.\*
 
-for f in ${MANDIR}/man5/shorewall* ${MANDIR}/man8/shorewall*; do
+if [ $PRODUCT = shorewall ]; then
+    remove_file_with_wildcard ${PERLLIBDIR}/$Product/\*
+    remove_directory ${SHAREDIR}/$PRODUCT/Samples
+    remove_directory ${SHAREDIR}/$PRODUCT/$Product
+    remove_file  ${SHAREDIR}/$PRODUCT/lib.cli-std
+    remove_file  ${SHAREDIR}/$PRODUCT/lib.runtime
+    remove_file  ${SHAREDIR}/$PRODUCT/compiler.pl
+    remove_file_with_wildcard  ${SHAREDIR}/$PRODUCT/prog.\*
+    remove_file  ${SHAREDIR}/$PRODUCT/init
+else
+    remove_directory ${SHAREDIR}/$PRODUCT
+fi
+
+for f in ${MANDIR}/man5/${PRODUCT}* ${MANDIR}/man8/${PRODUCT}*; do
     case $f in
-	shorewall6*|shorewall-lite*)
+	shorewall[6]-lite*)
 	    ;;
 	*)
-	    rm -f $f
+	    remove_file $f
 	    ;;
     esac
 done
 
-rm -f  ${CONFDIR}/logrotate.d/shorewall
-
-[ -n "$SYSTEMD" ] && rm -f  ${SYSTEMD}/shorewall.service
-
-echo "Shorewall Uninstalled"
+remove_file  ${CONFDIR}/logrotate.d/$PRODUCT
 
+[ -n "$SYSTEMD" ] && remove_file ${SYSTEMD}/${PRODUCT}.service
 
+#
+# Report Success
+#
+echo "$Product $VERSION Uninstalled"
